@@ -1,4 +1,8 @@
-weather = {
+from typing import Literal, Mapping, Optional, Union
+
+from ..eorzea_lang import EorzeaLang
+
+weather: Mapping[int, Mapping[Union[EorzeaLang, Literal['de', 'en', 'fr', 'ja']], Optional[str]]] = {
     0: {'de': None, 'en': None, 'fr': None, 'ja': None},
     1: {'de': 'Klar', 'en': 'Clear Skies', 'fr': 'Dégagé', 'ja': '快晴'},
     2: {'de': 'Heiter', 'en': 'Fair Skies', 'fr': 'Clair', 'ja': '晴れ'},
