@@ -1,4 +1,6 @@
-weather_rate = {
+from typing import Mapping, Sequence, Tuple
+
+weather_rate: Mapping[int, Sequence[Tuple[int, int]]] = {
     0: [(100, 2)],
     1: [(5, 7), (20, 7), (30, 4), (40, 3), (55, 2), (85, 1), (100, 2)],
     2: [(5, 7), (20, 7), (30, 4), (40, 3), (55, 2), (85, 1), (100, 2)],
@@ -146,5 +148,18 @@ weather_rate = {
     144: [(100, 161)],
     145: [(100, 157)],
     146: [(100, 128)],
-    147: [(100, 162)]
+    147: [(100, 162)],
+    148: [(25, 1), (70, 2), (80, 3), (90, 7), (95, 4), (100, 8)],
+    149: [(100, 171)],
+    150: [],
+    151: [],
+    152: [],
+    153: [],
+    154: [],
+    155: [],
+    156: [],
+    157: [],
+    158: [],
+    159: [],
+    160: []
 }
