@@ -147,7 +147,11 @@ class EorzeaTime:
         return cls._now
 
     @classmethod
-    def weather_period(cls, step: Union[int, Literal['inf']] = 5) -> Iterator['EorzeaTime']:
+    def weather_period(
+        cls,
+        step: Union[int, Literal['inf']] = 5,
+        from_: Optional[float] = None
+    ) -> Iterator['EorzeaTime']:
         """
         generate weather period
 
@@ -157,10 +161,13 @@ class EorzeaTime:
             quantity of period you want, by default 5.
             'inf' means infinite.
 
+        from_ : Optional[float]
+            The base timestamp for calculate the weather period.
+
         Returns
         -------
-        Iterator[float]
-            a generator of weather period
+        Iterator[EorzeaTime]
+            a generator of weather period.
         """
 
         if not isinstance(step, (int, str)):
@@ -170,7 +177,7 @@ class EorzeaTime:
             if step != 'inf':
                 raise TypeError("integer or Literal['inf'] argument required")
 
-        ts = _time()
+        ts = from_ or _time()
         weather_start = cls(timestamp=ts - (ts % _LOCAL_WEATHER_INTERVAL))
 
         current_step = 0
@@ -193,23 +200,35 @@ class EorzeaTime:
             self.guardian
         )
 
-    def __lt__(self, that: 'EorzeaTime'):
-        return self.get_unix_time() < that.get_unix_time()
+    def __lt__(self, that: object):
+        if isinstance(that, self.__class__):
+            return self.get_unix_time() < that.get_unix_time()
+        return NotImplemented
 
-    def __le__(self, that: 'EorzeaTime'):
-        return self.get_unix_time() <= that.get_unix_time()
+    def __le__(self, that: object):
+        if isinstance(that, self.__class__):
+            return self.get_unix_time() <= that.get_unix_time()
+        return NotImplemented
 
-    def __eq__(self, that: 'EorzeaTime'):
-        return self.get_unix_time() == that.get_unix_time()
+    def __eq__(self, that: object):
+        if isinstance(that, self.__class__):
+            return self.get_unix_time() == that.get_unix_time()
+        return NotImplemented
 
-    def __ne__(self, that: 'EorzeaTime'):
-        return self.get_unix_time() != that.get_unix_time()
+    def __ne__(self, that: object):
+        if isinstance(that, self.__class__):
+            return self.get_unix_time() != that.get_unix_time()
+        return NotImplemented
 
-    def __ge__(self, that: 'EorzeaTime'):
-        return self.get_unix_time() >= that.get_unix_time()
+    def __ge__(self, that: object):
+        if isinstance(that, self.__class__):
+            return self.get_unix_time() >= that.get_unix_time()
+        return NotImplemented
 
-    def __gt__(self, that: 'EorzeaTime'):
-        return self.get_unix_time() > that.get_unix_time()
+    def __gt__(self, that: object):
+        if isinstance(that, self.__class__):
+            return self.get_unix_time() > that.get_unix_time()
+        return NotImplemented
 
 
 def _get_guardian_by_moon(moon: int) -> str:
